@@ -1,6 +1,4 @@
-# -*- ruby -*-
-#
-# Copyright (C) 2013-2015  Ruby-GNOME2 Project Team
+# Copyright (C) 2013-2018  Ruby-GNOME2 Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -21,6 +19,7 @@ require "open-uri"
 module GNOME2
   module Rake
     class ExternalPackage < Struct.new(:name,
+                                       :download_name,
                                        :base_name,
                                        :archive_base_name,
                                        :label,
@@ -47,8 +46,13 @@ module GNOME2
         resolve_value(super) || "gz"
       end
 
+      def download_name
+        resolve_value(super) || name
+      end
+
       def base_name
-        resolve_value(super) || "#{name}-#{version}"
+        resolve_value(super) ||
+          "#{name.split('/').last}-#{version.gsub(/\Av/, '')}"
       end
 
       def archive_base_name
@@ -113,6 +117,8 @@ module GNOME2
           latest_version_webkitgtk
         when :icu
           latest_version_icu
+        when :github
+          latest_version_github
         else
           nil
         end
@@ -132,20 +138,23 @@ module GNOME2
         when :gnome
           base_url = gnome_base_url
           release_series = version.gsub(/\A(\d+\.\d+)(?:[^\d].*)?\z/, '\1')
-          base_url << "/#{name}/#{release_series}"
+          base_url << "/#{download_name}/#{release_series}"
         when :freedesktop
           base_url = freedesktop_base_url
-          base_url << "/#{name}/release"
+          base_url << "/#{download_name}/release"
         when :freedesktop_gstreamer
           base_url = freedesktop_gstreamer_base_url
-          base_url << "/#{name}"
+          base_url << "/#{download_name}"
         when :gnu
           base_url = gnu_base_url
-          base_url << "/#{name}"
+          base_url << "/#{download_name}"
         when :webkitgtk
           base_url = webkitgtk_base_url
         when :icu
           base_url = "#{icu_base_url}/#{version}"
+        when :github
+          base_url = github_base_url
+          base_url << "/#{download_name}/releases/download/#{version}"
         else
           base_url = nil
         end
@@ -176,6 +185,10 @@ module GNOME2
         "http://download.icu-project.org/files/icu4c"
       end
 
+      def github_base_url
+        "https://github.com"
+      end
+
       def sort_versions(versions)
         versions.sort_by do |version|
           version.split(".").collect(&:to_i)
@@ -183,7 +196,7 @@ module GNOME2
       end
 
       def latest_version_gnome
-        base_url = "#{gnome_base_url}/#{name}"
+        base_url = "#{gnome_base_url}/#{download_name}"
         minor_versions = []
         open(base_url) do |index|
           index.read.scan(/<a (.+?)>/) do |content,|
@@ -217,7 +230,7 @@ module GNOME2
       end
 
       def latest_version_freedesktop
-        base_url = "#{freedesktop_base_url}/#{name}/release"
+        base_url = "#{freedesktop_base_url}/#{download_name}/release"
         versions = []
         open(base_url) do |index|
           index.read.scan(/<a (.+?)>/) do |content,|
@@ -233,7 +246,7 @@ module GNOME2
       end
 
       def latest_version_freedesktop_gstreamer
-        base_url = "#{freedesktop_gstreamer_base_url}/#{name}"
+        base_url = "#{freedesktop_gstreamer_base_url}/#{download_name}"
         versions = []
         open(base_url) do |index|
           index.read.scan(/<a (.+?)>/) do |content,|
@@ -255,7 +268,7 @@ module GNOME2
       end
 
       def latest_version_gnu
-        base_url = "#{gnu_base_url}/#{name}"
+        base_url = "#{gnu_base_url}/#{download_name}"
         versions = []
         open(base_url) do |index|
           index.read.scan(/<a (.+?)>/) do |content,|
@@ -301,17 +314,26 @@ module GNOME2
         sort_versions(versions).last
       end
 
+      def latest_version_github
+        latest_url = "#{github_base_url}/#{download_name}/releases/latest"
+        open(latest_url) do |latest_page|
+          return latest_page.base_uri.path.split("/").last
+        end
+      end
+
       class WindowsConfiguration < Struct.new(:build,
                                               :include_paths,
                                               :library_paths,
                                               :configure_args,
                                               :meson_args,
                                               :cmake_args,
+                                              :make_args,
                                               :cc_args,
                                               :patches,
                                               :built_file,
                                               :need_autogen,
                                               :need_autoreconf,
+                                              :force_to_disable_deplibs_check,
                                               :build_concurrently,
                                               :use_cc_environment_variable,
                                               :gobject_introspection_compiler_split_args,
@@ -351,6 +373,10 @@ module GNOME2
           super || []
         end
 
+        def make_args
+          super || []
+        end
+
         def patches
           super || []
         end
@@ -367,6 +393,14 @@ module GNOME2
           need_autoreconf.nil? ? false : need_autoreconf
         end
 
+        def force_to_disable_deplibs_check?
+          if force_to_disable_deplibs_check.nil?
+            false
+          else
+            force_to_disable_deplibs_check
+          end
+        end
+
         def build_concurrently?
           build_concurrently.nil? ? true : build_concurrently
         end
